==> brlcad-7.32.6-1-x86_64.pkg.tar.zst: opt/brlcad/include/brlcad/brlcad_config.h <==
/**** Define statements for CMake ****/
#if !defined(BRLCADBUILD)
  #  pragma message "Warning: included brlcad_config.h (compile-time API) without BRLCADBUILD defined"
#endif
#if !defined(HAVE_CONFIG_H)
  #  pragma message "Warning: included brlcad_config.h (compile-time API) without HAVE_CONFIG_H defined"
#endif
#ifndef __CONFIG_H__
#define __CONFIG_H__
#define PACKAGE "brlcad"
#define PACKAGE_BUGREPORT "https://brlcad.org"
#define PACKAGE_NAME "BRL-CAD"
#define PACKAGE_STRING "BRL-CAD 7.32.6"
#define PACKAGE_TARNAME "brlcad"
#define EXECUTABLE_SUFFIX ""
#define SHARED_LIBRARY_SUFFIX ".so"
#define BRLCAD_ROOT "/opt/brlcad"
#define BRLCAD_BIN_DIR "bin"
#define BRLCAD_LIB_DIR "lib"
#define BRLCAD_LIBEXEC_DIR "libexec"
#define BRLCAD_INCLUDE_DIR "include"
#define BRLCAD_DATA_DIR "share"
#define BRLCAD_DOC_DIR "share/doc"
#define BRLCAD_MAN_DIR "share/man"
#define NDEBUG 1
#define SIZEOF_VOID_P 8
#ifndef __WORDSIZE
#  define __WORDSIZE 64
#endif
#define HAVE_XRENDER 1
#define PARALLEL 1
#if !defined(inline) && !defined(__cplusplus)
#  define inline inline
#endif /* !inline && !__cplusplus */
#ifndef _FORTIFY_SOURCE
#  define _FORTIFY_SOURCE 2
#endif
#define HAVE_PRINTF12_ATTRIBUTE 1
#define HAVE_PRINTF23_ATTRIBUTE 1
#define HAVE_SCANF23_ATTRIBUTE 1
#define HAVE_NORETURN_ATTRIBUTE 1
#define HAVE_ALWAYS_INLINE_ATTRIBUTE 1
#define HAVE_COLD_ATTRIBUTE 1
#define HAVE_NONNULL_ATTRIBUTE 1
#define HAVE_WARN_UNUSED_RESULT_ATTRIBUTE 1
#define HAVE_FLATTEN_ATTRIBUTE 1
#define PROBE_PTHREAD_H 1
#define HAVE_X11_XLIB_H 1
#define HAVE_X11_EXTENSIONS_XINPUT_H 1
#define STDC_HEADERS 1
#define HAVE_SYS_WAIT_H 1
#define HAVE_DIRENT_H 1
#define HAVE_ARPA_INET_H 1
#define HAVE_DLFCN_H 1
#define HAVE_EMMINTRIN_H 1
#define HAVE_GETOPT_H 1
#define HAVE_GRP_H 1
#define HAVE_INTTYPES_H 1
#define HAVE_LIBGEN_H 1
#define HAVE_MEMORY_H 1
#define HAVE_NETDB_H 1
#define HAVE_NETINET_IN_H 1
#define HAVE_POLL_H 1
#define HAVE_PTHREAD_H 1
#define HAVE_PWD_H 1
#define HAVE_SCHED_H 1
#define HAVE_SGTTY_H 1
#define HAVE_SIGNAL_H 1
#define HAVE_STDINT_H 1
#define HAVE_STDLIB_H 1
#define HAVE_STRING_H 1
#define HAVE_STRINGS_H 1
#define HAVE_SYS_FILE_H 1
#define HAVE_SYS_IOCTL_H 1
#define HAVE_SYS_IPC_H 1
#define HAVE_SYS_MMAN_H 1
#define HAVE_SYS_MOUNT_H 1
#define HAVE_SYS_PARAM_H 1
#define HAVE_SYS_PRCTL_H 1
#define HAVE_SYS_RESOURCE_H 1
#define HAVE_SYS_SELECT_H 1
#define HAVE_SYS_SHM_H 1
#define HAVE_SYS_SOCKET_H 1
#define HAVE_SYS_STAT_H 1
#define HAVE_SYS_SYSINFO_H 1
#define HAVE_SYS_TIME_H 1
#define HAVE_SYS_TIMES_H 1
#define HAVE_SYS_TYPES_H 1
#define HAVE_SYS_UIO_H 1
#define HAVE_SYS_UN_H 1
#define HAVE_SYS_UTSNAME_H 1
#define HAVE_SYS_WAIT_H 1
#define HAVE_SYSLOG_H 1
#define HAVE_UNISTD_H 1
#define HAVE_UUID_UUID_H 1
#define HAVE_TERMIOS_H 1
#define HAVE_TERMIO_H 1
#define HAVE_ISTREAM 1
#define HAVE_LIMITS 1
#define HAVE_BASENAME 1
#define HAVE_DIRNAME 1
#define HAVE_GL_GL_H 1
#define HAVE_GL_GLX_H 1
#define HAVE_EMMINTRIN 1
#define HAVE_STRUCT_STAT_ST_BLKSIZE 1
#define HAVE_STRUCT_STAT_ST_BLOCKS 1
#define HAVE_STRUCT_STAT_ST_RDEV 1
#define HAVE_STRUCT_TIMESPEC 1
#define HAVE_SOCKLEN_T 1
#define SIZEOF_SOCKLEN_T 4
#define HAVE_CPU_SET_T 1
#define SIZEOF_CPU_SET_T 128
#define HAVE_INT 1
#define SIZEOF_INT 4
#define HAVE_LONG 1
#define SIZEOF_LONG 8
#define HAVE_LONG_LONG 1
#define SIZEOF_LONG_LONG 8
#define HAVE_OFF_T 1
#define SIZEOF_OFF_T 8
#define HAVE_PTRDIFF_T 1
#define SIZEOF_PTRDIFF_T 8
#define HAVE_SIZE_T 1
#define SIZEOF_SIZE_T 8
#define HAVE_SSIZE_T 1
#define SIZEOF_SSIZE_T 8
#define HAVE_UINT64_T 1
#define SIZEOF_UINT64_T 8
#define HAVE_UINTPTR_T 1
#define SIZEOF_UINTPTR_T 8
#define HAVE_OFF_T_64BIT 1
#define HAVE_THREAD_LOCAL 1
#define HAVE_PERCENT_Z 1
#define HAVE_STATIC_ARRAYS 1
#define HAVE_ALARM 1
#define HAVE_DECL_ALARM 1
#define HAVE_ASINH 1
#define HAVE_DECL_ASINH 1
#define HAVE_CONFSTR 1
#define HAVE_DECL_CONFSTR 1
#define HAVE_DLOPEN 1
#define HAVE_DLADDR 1
#define HAVE_DRAND48 1
#define HAVE_DECL_DRAND48 1
#define HAVE_FCHMOD 1
#define HAVE_DECL_FCHMOD 1
#define HAVE_FDOPEN 1
#define HAVE_DECL_FDOPEN 1
#define HAVE_FMEMOPEN 1
#define HAVE_DECL_FMEMOPEN 1
#define HAVE_FSEEKO 1
#define HAVE_DECL_FSEEKO 1
#define HAVE_FSYNC 1
#define HAVE_DECL_FSYNC 1
#define HAVE_GETCWD 1
#define HAVE_DECL_GETCWD 1
#define HAVE_GETEGID 1
#define HAVE_DECL_GETEGID 1
#define HAVE_GETEUID 1
#define HAVE_DECL_GETEUID 1
#define HAVE_GETHOSTBYNAME 1
#define HAVE_GETHOSTNAME 1
#define HAVE_DECL_GETHOSTNAME 1
#define HAVE_GETLOADAVG 1
#define HAVE_GETOPT_LONG 1
#define HAVE_DECL_GETOPT_LONG 1
#define HAVE_GETPID 1
#define HAVE_DECL_GETPID 1
#define HAVE_GETTIMEOFDAY 1
#define HAVE_DECL_GETTIMEOFDAY 1
#define HAVE_HTONL 1
#define HAVE_DECL_HTONL 1
#define HAVE_HYPOT 1
#define HAVE_DECL_HYPOT 1
#define HAVE_ISASCII 1
#define HAVE_DECL_ISASCII 1
#define HAVE_ISINF 1
#define HAVE_ISNAN 1
#define HAVE_LOGB 1
#define HAVE_DECL_LOGB 1
#define HAVE_LRAND48 1
#define HAVE_DECL_LRAND48 1
#define HAVE_LSEEK 1
#define HAVE_DECL_LSEEK 1
#define HAVE_MKSTEMP 1
#define HAVE_DECL_MKSTEMP 1
#define HAVE_MODFF 1
#define HAVE_DECL_MODFF 1
#define HAVE_NEXTAFTER 1
#define HAVE_DECL_NEXTAFTER 1
#define HAVE_NEXTAFTERF 1
#define HAVE_DECL_NEXTAFTERF 1
#define HAVE_PIPE 1
#define HAVE_DECL_PIPE 1
#define HAVE_POPEN 1
#define HAVE_DECL_POPEN 1
#define HAVE_POSIX_MEMALIGN 1
#define HAVE_DECL_POSIX_MEMALIGN 1
#define HAVE_PROGRAM_INVOCATION_NAME 1
#define HAVE_RANDOM 1
#define HAVE_DECL_RANDOM 1
#define HAVE_REALPATH 1
#define HAVE_DECL_REALPATH 1
#define HAVE_RINT 1
#define HAVE_DECL_RINT 1
#define HAVE_SETENV 1
#define HAVE_DECL_SETENV 1
#define HAVE_SETPGID 1
#define HAVE_DECL_SETPGID 1
#define HAVE_SETPRIORITY 1
#define HAVE_DECL_SETPRIORITY 1
#define HAVE_SETSID 1
#define HAVE_DECL_SETSID 1
#define HAVE_SHMAT 1
#define HAVE_DECL_SHMAT 1
#define HAVE_SHMCTL 1
#define HAVE_DECL_SHMCTL 1
#define HAVE_SHMDT 1
#define HAVE_DECL_SHMDT 1
#define HAVE_SHMGET 1
#define HAVE_DECL_SHMGET 1
#define HAVE_SNPRINTF 1
#define HAVE_DECL_SNPRINTF 1
#define HAVE_SRAND48 1
#define HAVE_DECL_SRAND48 1
#define HAVE_STRCASECMP 1
#define HAVE_STRDUP 1
#define HAVE_DECL_STRDUP 1
#define HAVE_STRNCASECMP 1
#define HAVE_STRTOLL 1
#define HAVE_DECL_STRTOLL 1
#define HAVE_SYNC 1
#define HAVE_DECL_SYNC 1
#define HAVE_SYSCONF 1
#define HAVE_DECL_SYSCONF 1
#define HAVE_TIME 1
#define HAVE_TOASCII 1
#define HAVE_DECL_TOASCII 1
#define HAVE_TZSET 1
#define HAVE_UNAME 1
#define HAVE_VFORK 1
#define HAVE_VSNPRINTF 1
#define HAVE_DECL_VSNPRINTF 1
#define HAVE_VSSCANF 1
#define HAVE_DECL_VSSCANF 1
#define HAVE_WAIT 1
#define HAVE_DECL_WAIT 1
#define HAVE_WRITEV 1
#define HAVE_DECL_WRITEV 1
#define HAVE_ALLOCA 1
#define HAVE_KILL 1
#define HAVE_DECL_KILL 1
#define HAVE_FILENO 1
#define HAVE_DECL_FILENO 1
#define HAVE_DAEMON 1
#define HAVE_WORKING_REALPATH 1
#define HAVE_LRINT 1
#define HAVE_DECL_LRINT 1
#define HAVE_DECL_LRINT 1
#define HAVE_TGAMMA 1
#define HAVE_DECL_TGAMMA 1
#define HAVE_GETHOSTBYADDR 1
#define HAVE_DECL_GETHOSTBYADDR 1
#define HAVE_CXX_LOGB 1
#define HAVE_REGEX_H 1
#define HAVE_TCL_H 1
#define HAVE_TK_H 1
#define HAVE_TK
#define ITCL_VERSION	"3.4"
#define ITK_VERSION	"3.4"
#define IWIDGETS_VERSION "4.1.1"
#endif /* __CONFIG_H__ */

==> brlcad-7.36.0-1-x86_64.pkg.tar.zst: opt/brlcad/include/brlcad/brlcad_config.h <==
/**** Define statements for CMake ****/
#if !defined(BRLCADBUILD)
  #  pragma message "Warning: included brlcad_config.h (compile-time API) without BRLCADBUILD defined"
#endif
#if !defined(HAVE_CONFIG_H)
  #  pragma message "Warning: included brlcad_config.h (compile-time API) without HAVE_CONFIG_H defined"
#endif
#ifndef __CONFIG_H__
#define __CONFIG_H__
#define PACKAGE "brlcad"
#define PACKAGE_BUGREPORT "https://brlcad.org"
#define PACKAGE_NAME "BRL-CAD"
#define PACKAGE_STRING "BRL-CAD 7.36.0"
#define PACKAGE_TARNAME "brlcad"
#define EXECUTABLE_SUFFIX ""
#define SHARED_LIBRARY_SUFFIX ".so"
#define BRLCAD_ROOT "/opt/brlcad"
#define BRLCAD_BIN_DIR "bin"
#define BRLCAD_LIB_DIR "lib"
#define BRLCAD_LIBEXEC_DIR "libexec"
#define BRLCAD_INCLUDE_DIR "include"
#define BRLCAD_DATA_DIR "share"
#define BRLCAD_DOC_DIR "share/doc"
#define BRLCAD_MAN_DIR "share/man"
#define NDEBUG 1
#define CXX_STANDARD 14
#define SIZEOF_VOID_P 8
#ifndef __WORDSIZE
#  define __WORDSIZE 64
#endif
#define HAVE_XRENDER 1
#define BRLCAD_OPENGL 1
#define PARALLEL 1
#if !defined(inline) && !defined(__cplusplus)
#  define inline inline
#endif /* !inline && !__cplusplus */
#ifndef _FORTIFY_SOURCE
#  define _FORTIFY_SOURCE 2
#endif
#define HAVE_PRINTF12_ATTRIBUTE 1
#define HAVE_PRINTF23_ATTRIBUTE 1
#define HAVE_SCANF23_ATTRIBUTE 1
#define HAVE_DEPRECATED_ATTRIBUTE 1
#define HAVE_NORETURN_ATTRIBUTE 1
#define HAVE_ALWAYS_INLINE_ATTRIBUTE 1
#define HAVE_COLD_ATTRIBUTE 1
#define HAVE_HOT_ATTRIBUTE 1
#define HAVE_NONNULL_ATTRIBUTE 1
#define HAVE_WARN_UNUSED_RESULT_ATTRIBUTE 1
#define HAVE_FLATTEN_ATTRIBUTE 1
#define PROBE_PTHREAD_H 1
#define HAVE_X11_XLIB_H 1
#define HAVE_X11_EXTENSIONS_XINPUT_H 1
#define STDC_HEADERS 1
#define HAVE_SYS_WAIT_H 1
#define HAVE_DIRENT_H 1
#define HAVE_ARPA_INET_H 1
#define HAVE_DLFCN_H 1
#define HAVE_EMMINTRIN_H 1
#define HAVE_GETOPT_H 1
#define HAVE_GL_GL_H 1
#define HAVE_GLOB_H 1
#define HAVE_GRP_H 1
#define HAVE_INTTYPES_H 1
#define HAVE_LIBGEN_H 1
#define HAVE_MEMORY_H 1
#define HAVE_NETDB_H 1
#define HAVE_NETINET_IN_H 1
#define HAVE_POLL_H 1
#define HAVE_PTHREAD_H 1
#define HAVE_PWD_H 1
#define HAVE_SCHED_H 1
#define HAVE_SGTTY_H 1
#define HAVE_SIGNAL_H 1
#define HAVE_STDINT_H 1
#define HAVE_STDLIB_H 1
#define HAVE_STRING_H 1
#define HAVE_STRINGS_H 1
#define HAVE_SYS_FILE_H 1
#define HAVE_SYS_IOCTL_H 1
#define HAVE_SYS_IPC_H 1
#define HAVE_SYS_MMAN_H 1
#define HAVE_SYS_MOUNT_H 1
#define HAVE_SYS_PARAM_H 1
#define HAVE_SYS_PRCTL_H 1
#define HAVE_SYS_RESOURCE_H 1
#define HAVE_SYS_SELECT_H 1
#define HAVE_SYS_SHM_H 1
#define HAVE_SYS_SOCKET_H 1
#define HAVE_SYS_STAT_H 1
#define HAVE_SYS_SYSINFO_H 1
#define HAVE_SYS_TIME_H 1
#define HAVE_SYS_TIMES_H 1
#define HAVE_SYS_TYPES_H 1
#define HAVE_SYS_UIO_H 1
#define HAVE_SYS_UN_H 1
#define HAVE_SYS_UTSNAME_H 1
#define HAVE_SYS_WAIT_H 1
#define HAVE_SYSLOG_H 1
#define HAVE_UNISTD_H 1
#define HAVE_UUID_UUID_H 1
#define HAVE_TERMIOS_H 1
#define HAVE_TERMIO_H 1
#define HAVE_ISTREAM 1
#define HAVE_LIMITS 1
#define HAVE_BASENAME 1
#define HAVE_DIRNAME 1
#define HAVE_EMMINTRIN 1
#define HAVE_STRUCT_STAT_ST_BLKSIZE 1
#define HAVE_STRUCT_STAT_ST_BLOCKS 1
#define HAVE_STRUCT_STAT_ST_RDEV 1
#define HAVE_STRUCT_TIMESPEC 1
#define HAVE_SOCKLEN_T 1
#define SIZEOF_SOCKLEN_T 4
#define HAVE_CPU_SET_T 1
#define SIZEOF_CPU_SET_T 128
#define HAVE_INT 1
#define SIZEOF_INT 4
#define HAVE_LONG 1
#define SIZEOF_LONG 8
#define HAVE_LONG_LONG 1
#define SIZEOF_LONG_LONG 8
#define HAVE_OFF_T 1
#define SIZEOF_OFF_T 8
#define HAVE_PTRDIFF_T 1
#define SIZEOF_PTRDIFF_T 8
#define HAVE_SIZE_T 1
#define SIZEOF_SIZE_T 8
#define HAVE_SSIZE_T 1
#define SIZEOF_SSIZE_T 8
#define HAVE_UINT64_T 1
#define SIZEOF_UINT64_T 8
#define HAVE_UINTPTR_T 1
#define SIZEOF_UINTPTR_T 8
#define HAVE_OFF_T_64BIT 1
#define HAVE_THREAD_LOCAL 1
#define HAVE_PERCENT_Z 1
#define HAVE_STATIC_ARRAYS 1
#define HAVE_ALARM 1
#define HAVE_DECL_ALARM 1
#define HAVE_ASINH 1
#define HAVE_DECL_ASINH 1
#define HAVE_CONFSTR 1
#define HAVE_DECL_CONFSTR 1
#define HAVE_DLOPEN 1
#define HAVE_DLADDR 1
#define HAVE_DRAND48 1
#define HAVE_DECL_DRAND48 1
#define HAVE_FCHMOD 1
#define HAVE_DECL_FCHMOD 1
#define HAVE_FDOPEN 1
#define HAVE_DECL_FDOPEN 1
#define HAVE_FMEMOPEN 1
#define HAVE_DECL_FMEMOPEN 1
#define HAVE_FSEEKO 1
#define HAVE_DECL_FSEEKO 1
#define HAVE_FSYNC 1
#define HAVE_DECL_FSYNC 1
#define HAVE_GETCWD 1
#define HAVE_DECL_GETCWD 1
#define HAVE_GETEGID 1
#define HAVE_DECL_GETEGID 1
#define HAVE_GETEUID 1
#define HAVE_DECL_GETEUID 1
#define HAVE_GETHOSTNAME 1
#define HAVE_DECL_GETHOSTNAME 1
#define HAVE_GETLOADAVG 1
#define HAVE_GETOPT_LONG 1
#define HAVE_DECL_GETOPT_LONG 1
#define HAVE_GETPID 1
#define HAVE_DECL_GETPID 1
#define HAVE_GETTIMEOFDAY 1
#define HAVE_DECL_GETTIMEOFDAY 1
#define HAVE_HTONL 1
#define HAVE_DECL_HTONL 1
#define HAVE_HYPOT 1
#define HAVE_DECL_HYPOT 1
#define HAVE_ISASCII 1
#define HAVE_DECL_ISASCII 1
#define HAVE_ISINF 1
#define HAVE_ISNAN 1
#define HAVE_LOGB 1
#define HAVE_DECL_LOGB 1
#define HAVE_LRAND48 1
#define HAVE_DECL_LRAND48 1
#define HAVE_LSEEK 1
#define HAVE_DECL_LSEEK 1
#define HAVE_MKSTEMP 1
#define HAVE_DECL_MKSTEMP 1
#define HAVE_MODFF 1
#define HAVE_DECL_MODFF 1
#define HAVE_NEXTAFTER 1
#define HAVE_DECL_NEXTAFTER 1
#define HAVE_NEXTAFTERF 1
#define HAVE_DECL_NEXTAFTERF 1
#define HAVE_PIPE 1
#define HAVE_DECL_PIPE 1
#define HAVE_POPEN 1
#define HAVE_DECL_POPEN 1
#define HAVE_POSIX_MEMALIGN 1
#define HAVE_DECL_POSIX_MEMALIGN 1
#define HAVE_PROGRAM_INVOCATION_NAME 1
#define HAVE_RANDOM 1
#define HAVE_DECL_RANDOM 1
#define HAVE_REALPATH 1
#define HAVE_DECL_REALPATH 1
#define HAVE_RINT 1
#define HAVE_DECL_RINT 1
#define HAVE_SETENV 1
#define HAVE_DECL_SETENV 1
#define HAVE_SETPGID 1
#define HAVE_DECL_SETPGID 1
#define HAVE_SETPRIORITY 1
#define HAVE_DECL_SETPRIORITY 1
#define HAVE_SETSID 1
#define HAVE_DECL_SETSID 1
#define HAVE_SHMAT 1
#define HAVE_DECL_SHMAT 1
#define HAVE_SHMCTL 1
#define HAVE_DECL_SHMCTL 1
#define HAVE_SHMDT 1
#define HAVE_DECL_SHMDT 1
#define HAVE_SHMGET 1
#define HAVE_DECL_SHMGET 1
#define HAVE_SNPRINTF 1
#define HAVE_DECL_SNPRINTF 1
#define HAVE_SRAND48 1
#define HAVE_DECL_SRAND48 1
#define HAVE_STRCASECMP 1
#define HAVE_STRDUP 1
#define HAVE_DECL_STRDUP 1
#define HAVE_STRLCAT 1
#define HAVE_STRLCPY 1
#define HAVE_STRNCASECMP 1
#define HAVE_STRTOLL 1
#define HAVE_DECL_STRTOLL 1
#define HAVE_SYNC 1
#define HAVE_DECL_SYNC 1
#define HAVE_TIME 1
#define HAVE_TOASCII 1
#define HAVE_DECL_TOASCII 1
#define HAVE_TZSET 1
#define HAVE_UNAME 1
#define HAVE_VFORK 1
#define HAVE_VSNPRINTF 1
#define HAVE_DECL_VSNPRINTF 1
#define HAVE_VSSCANF 1
#define HAVE_DECL_VSSCANF 1
#define HAVE_WAIT 1
#define HAVE_DECL_WAIT 1
#define HAVE_WRITEV 1
#define HAVE_DECL_WRITEV 1
#define HAVE_ALLOCA 1
#define HAVE_KILL 1
#define HAVE_DECL_KILL 1
#define HAVE_FILENO 1
#define HAVE_DECL_FILENO 1
#define HAVE_DAEMON 1
#define HAVE_SYSCONF 1
#define HAVE_DECL_SYSCONF 1
#define HAVE_SYSCONF_AVPHYS 1
#define HAVE_WORKING_REALPATH 1
#define HAVE_LRINT 1
#define HAVE_DECL_LRINT 1
#define HAVE_DECL_LRINT 1
#define HAVE_TGAMMA 1
#define HAVE_DECL_TGAMMA 1
#define HAVE_GETHOSTBYADDR 1
#define HAVE_DECL_GETHOSTBYADDR 1
#define HAVE_GETHOSTBYNAME 1
#define HAVE_DECL_GETHOSTBYNAME 1
#define HAVE_CXX_LOGB 1
#define HAVE_TK
#define ITCL_VERSION "3.4"
#define ITK_VERSION "3.4"
#define IWIDGETS_VERSION "4.1.1"
#endif /* __CONFIG_H__ */
